OC.L10N.register(
    "settings",
    {
    "Wrong current password" : "現在のパスワードが間違っています",
    "The new password cannot be the same as the previous one" : "新しいパスワードは前のパスワードと同じにできません",
    "No user supplied" : "ユーザーが指定されていません",
    "Authentication error" : "認証エラー",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "リカバリ用の管理者パスワードを入力してください。そうでない場合は、全ユーザーのデータが失われます。",
    "Wrong admin recovery password. Please check the password and try again." : "リカバリ用の管理者パスワードが間違っています。パスワードを確認して再度実行してください。",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "バックエンドはパスワードの変更をサポートしていませんが、ユーザーの暗号化キーは正常に更新されました。",
    "Unable to change password" : "パスワードを変更できません",
    "%s password changed successfully" : "%s パスワードは正常に変更されました",
    "Couldn't send reset email. Please contact your administrator." : "リセットメールを送信できませんでした。管理者に問い合わせてください。",
    "installing and updating apps via the market or Federated Cloud Sharing" : "アプリストアまたはクラウド連携共有からアプリをインストール/アップデート",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "%s バージョン (%s) の古い cURL を使っています。OSを更新するか、この機能 %s が正しく動くアプリに更新してください。",
    "Invalid url '%s'. Urls should be set up like 'http://www.example.com' or 'https://www.example.com'" : "無効なURL '%s' です。URLは'http://www.example.com' や 'https://www.example.com' のように設定する必要があります。",
    "Group already exists." : "グループはすでに存在しています",
    "Unable to add group." : "グループを追加できません",
    "Unable to delete group." : "グループを削除できません",
    "Saved" : "保存されました",
    "log-level out of allowed range" : "ログレベルが許可された範囲を超えています",
    "Invalid email address" : "無効なメールアドレス",
    "test email settings" : "メール設定のテスト",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "メールの送信中に問題が発生しました。設定を確認してください。 (Error: %s)",
    "Email sent" : "メールを送信しました",
    "You need to set your user email before being able to send test emails." : "ユーザーメールを設定して初めて、テストメールを送信することができるようになります。",
    "Couldn't change the email address because the user does not exist" : "ユーザが存在しない為、emailアドレスを変更出来ませんでした。",
    "Couldn't change the email address because the token is invalid" : "無効なトークンを利用している為、emailアドレスが変更出来ませんでした。",
    "Your %s account was created" : "アカウント %s を作成しました",
    "A user with that name already exists." : "そのユーザー名はすでに存在します。",
    "Unable to create user." : "ユーザーを追加できません。",
    "Failed to set password. Please contact the administrator." : "パスワードの設定に失敗しました。管理者に問い合わせてください。",
    "Failed to set password. Please contact your administrator." : "パスワードの設定に失敗しました。管理者に問い合わせてください。",
    "Failed to send email. Please contact your administrator." : "メール送信に失敗しました。管理者に問い合わせてください。",
    "Unable to delete user." : "ユーザーを削除できません。",
    "Forbidden" : "禁止",
    "Invalid user" : "無効なユーザー",
    "Unable to change mail address" : "メールアドレスを変更できません",
    "Email has been changed successfully." : "メールアドレスが正常に変更されました。",
    "An email has been sent to this address for confirmation. Until the email is verified this address will not be set." : "設定したメールアドレスに確認のためのメールを送りました。\nメールアドレスが承認されるまでこのアドレスは設定されません。",
    "No email was sent because you already sent one recently. Please try again later." : "最近、既に同様のメールを送信しているため、メールは送られませんでした。",
    "Unable to change display name" : "表示名を変更できません",
    "Your full name has been changed." : "名前を変更しました。",
    "Unable to change full name" : "名前を変更できません",
    "%s email address confirm" : "%s確認用のメールアドレス",
    "Couldn't send email address change confirmation mail. Please contact your administrator." : "emailアドレス変更の確認メールを送信できませんでした。管理者に問い合わせてください。",
    "%s email address changed successfully" : "%sメールアドレスを変更しました",
    "Couldn't send email address change notification mail. Please contact your administrator." : "メールアドレスの変更を通知するメールを送ることができませんでした。\n管理者に問い合わせてください。",
    "Unable to enable/disable user." : "ユーザの有効化/無効化に失敗しました。",
    "Invalid mail address" : "無効なメールアドレスです",
    "Owner language" : "所有者の言語",
    "Create" : "作成",
    "Change" : "更新",
    "Delete" : "削除",
    "Share" : "共有",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Language changed" : "言語が変更されました",
    "Invalid request" : "不正なリクエスト",
    "Admins can't remove themself from the admin group" : "管理者は自身を管理者グループから削除できません。",
    "Unknown user" : "不明なユーザー",
    "Couldn't remove app." : "アプリが削除できませんでした。",
    "Official" : "公式",
    "Approved" : "承認済み",
    "All" : "すべて",
    "Enabled" : "有効なアプリ",
    "Not enabled" : "無効なアプリ",
    "No apps found for your version" : "現在のバージョンに対応するアプリはありません",
    "The app will be downloaded from the app store" : "このアプリは、アプリストアからダウンロードできます。",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "公式アプリは ownCloud コミュニティにより開発されています。公式アプリは ownCloud の中心的な機能を提供し、製品として可能です。",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "承認されたアプリは信頼された開発者により開発され、大まかなセキュリティチェックに合格しています。アプリは積極的にオープンソースコードレポジトリでメンテナンスされ、メンテナは通常の用途では安定していると考えます。",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "このアプリはセキュリティチェックされていません、新規アプリか安定性が確認されていないアプリです。自己責任でインストールしてください。",
    "Please wait...." : "しばらくお待ちください...",
    "Error while disabling app" : "アプリ無効化中にエラーが発生",
    "Disable" : "無効",
    "Enable" : "有効にする",
    "Error while enabling app" : "アプリを有効にする際にエラーが発生",
    "Error: this app cannot be enabled because it makes the server unstable" : "エラー：このアプリは、サーバーを不安定にするため、有効にすることができません。",
    "Error: could not disable broken app" : "エラー: 壊れたアプリを無効にできませんでした",
    "Error while disabling broken app" : "壊れたアプリの無効化中にエラーが発生",
    "Updating...." : "更新中....",
    "Error while updating app" : "アプリの更新中にエラーが発生",
    "Updated" : "アップデート済み",
    "Uninstalling ...." : "アンインストール中 ....",
    "Error while uninstalling app" : "アプリをアンインストール中にエラーが発生",
    "Uninstall" : "アンインストール",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "アプリは有効ですが、更新が必要です。5秒後に更新ページにリダイレクトします。",
    "App update" : "アプリのアップデート",
    "Experimental" : "実験的",
    "No apps found for {query}" : "{query} に対応するアプリはありません",
    "Migration in progress. Please wait until the migration is finished" : "移行の処理中です。移行が完了するまでお待ちください。",
    "Migration started …" : "移行を開始しました…",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "エラーが発生しました。ASCIIコードのPEM証明書をアップロードしてください。",
    "Valid until {date}" : "{date} まで有効",
    "Disconnect" : "切断",
    "Error while loading browser sessions and device tokens" : "ブラウザーセッションとデバイストークンの読み込みにおけるエラー",
    "Empty app name is not allowed." : "空のアプリ名は許可されていません。",
    "Error while creating device token" : "デバイストークンの作成におけるエラー",
    "Error while deleting the token" : "トークンの削除におけるエラー",
    "Are you sure you want to remove this domain?" : "このドメインを削除しますか？",
    "CORS" : "CORS",
    "Sending..." : "送信中…",
    "Failed to change the email address." : "メールアドレスの変更に失敗しました。",
    "Email changed successfully for {user}." : "{user}のメールアドレスが正常に変更されました。",
    "An error occurred: {message}" : "エラーが発生しました: {message}",
    "Select a profile picture" : "プロファイル画像を選択",
    "Very weak password" : "非常に弱いパスワード",
    "Weak password" : "弱いパスワード",
    "So-so password" : "まずまずのパスワード",
    "Good password" : "良好なパスワード",
    "Strong password" : "強いパスワード",
    "Passwords do not match" : "パスワードが一致しません",
    "Groups" : "グループ",
    "Unable to delete {objName}" : "{objName} を削除できません",
    "Error creating group: {message}" : "グループの作成エラー: {message}",
    "A valid group name must be provided" : "有効なグループ名を指定する必要があります",
    "Delete group" : "グループを削除",
    "Resend invitation email" : "招待メールを再送信",
    "never" : "なし",
    "unknown" : "不明",
    "Delete user" : "ユーザーを削除",
    "Invalid quota value \"{val}\"" : "クオータ \"{val}\" は不正な値です。",
    "enabled" : "有効",
    "disabled" : "無効",
    "User {uid} has been {state}!" : "ユーザ(uid={uid})は{state}状態です",
    "no group" : "未グループ",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "このユーザーのデータ復旧が無効になっていますので、パスワードを変更するとユーザーはデータに二度とアクセスできません。",
    "Password successfully changed" : "パスワードは正常に変更されました",
    "A valid username must be provided" : "有効なユーザー名を指定する必要があります",
    "Error creating user: {message}" : "ユーザー作成エラー: {message}",
    "A valid password must be provided" : "有効なパスワードを指定する必要があります",
    "A valid email must be provided" : "有効なメールアドレスを指定する必要があります",
    "Use the following link to confirm your changes to the email address: {link}" : "以下のリンクを利用してemailアドレスの変更を承認してください : {link}",
    "Email address changed to {mailAddress} successfully." : "emailアドレスの {mailAddress} への変更に成功しました。",
    "Cheers!" : "それでは！",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "こんにちは、\n\nあなたのアカウント %s が利用可能になったことをお知らせします。\n\nユーザー名: %s\n接続URL: %s\n\n",
    "Language" : "言語",
    "Apps Management" : "アプリ管理",
    "Developer documentation" : "開発者ドキュメント",
    "by %s" : "%s による",
    "%s-licensed" : "%s ライセンス",
    "Documentation:" : "ドキュメント:",
    "User documentation" : "ユーザードキュメント",
    "Admin documentation" : "管理者ドキュメント",
    "Visit website" : "ウェブサイトを表示",
    "Report a bug" : "バグを報告",
    "Show description …" : "説明を表示 ...",
    "Hide description …" : "説明を隠す ...",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "このアプリはownCloudの最小バージョンが指定されていません．ownCloud 11 以降でエラーが発生する可能性があります.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "このアプリはownCloud バージョンの上限が指定されていません．ownCloud 11 以降でエラーが発生する可能性があります.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "次の依存関係が満たされないためこのアプリをインストールできません:",
    "Enable only for specific groups" : "特定のグループのみ有効に",
    "Uninstall App" : "アプリをアンインストール",
    "Show enabled apps" : "有効なアプリを表示する",
    "Show disabled apps" : "無効なアプリを表示する",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "最終cronジョブ実行: %s",
    "Last cron job execution: %s. Something seems wrong." : "最終cronジョブ実行: %s  何らかの問題があります。",
    "Cron was not executed yet!" : "cronはまだ実行されていません！",
    "Open documentation" : "ドキュメントを開く",
    "Execute one task with each page loaded" : "各ページの読み込み時にタスクを実行します。",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.phpは、HTTP経由で15分ごとにcron.phpを実行するようwebcronサービスに登録されます。",
    "Use system's cron service to call the cron.php file every 15 minutes." : "システムのcronサービスを利用して、15分間隔でcron.phpファイルを実行します。",
    "SSL Root Certificates" : "SSLルート証明書",
    "Common Name" : "コモンネーム",
    "Valid until" : "有効期限",
    "Issued By" : "発行元",
    "Valid until %s" : "%s まで有効",
    "Import root certificate" : "ルート証明書をインポート",
    "Server-side encryption" : "サーバーサイド暗号化",
    "Enable server-side encryption" : "サーバーサイド暗号化を有効にする",
    "Please read carefully before activating server-side encryption: " : "サーバーサイド暗号化を有効にする前によくお読みください:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "暗号化を一度有効化すると、この時点からサーバーにアップロードされるファイルの全てが暗号化されサーバー上に入ります。有効化された暗号モジュールは復号化機能をサポートしますが、すべての前提条件が満たされている(例えば、回復キーが設定されている)場合にのみ、後日暗号化を無効にすることが可能です。",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "暗号化だけで、システムのセキュリティが保証されるものではありません。暗号化アプリがどのように動作するかの詳細について、およびサポートされているユースケースについてはownCloudのドキュメントを参照してください。",
    "Be aware that encryption always increases the file size." : "暗号化は、常にファイルサイズが増加することに注意してください。",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "暗号化した場合には必ず、あなたのデータと共に暗号化キーをバックアップすることを確認し、定期的にデータをバックアップを作成することをお勧めします。",
    "This is the final warning: Do you really want to enable encryption?" : "これが最後の警告です：本当に暗号化を有効にしますか？",
    "Enable encryption" : "暗号化を有効に",
    "No encryption module loaded, please enable an encryption module in the app menu." : "暗号化モジュールがロードされていません。アプリのメニューから暗号化モジュールを有効化してください。",
    "Select default encryption module:" : "デフォルトの暗号化モジュールを選択:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "古い暗号化(ownCloud <= 8.0) から新しいものに暗号化キーを移行する必要があります。\"デフォルトの暗号化モジュール\" を有効にして 'occ encryption:migrate' を実行してください。",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "古い暗号化(ownCloud <= 8.0) から新しいものに暗号化キーを移行する必要があります。",
    "Start migration" : "移行を開始",
    "Sharing" : "共有",
    "Allow apps to use the Share API" : "アプリからの共有APIの利用を許可する",
    "Allow users to share via link" : "URLリンクでの共有を許可する",
    "Allow public uploads" : "パブリックなアップロードを許可する",
    "Enforce password protection for read-only links" : "読取専用のリンクにパスワードによる保護を強制する",
    "Enforce password protection for upload-only (File Drop) links" : "アップロード（File Drop）のみのリンクにパスワードによる保護を強制する",
    "Set default expiration date" : "有効期限のデフォルト値を設定する",
    "Expire after " : "無効になるまで",
    "days" : "日",
    "Allow users to send mail notification for shared files" : "共有ファイルに関するメール通知の送信をユーザーに許可する",
    "Language used for public mail notifications for shared files" : "共有ファイルメール通知に使用する言語",
    "Allow users to share file via social media" : "ユーザーがソーシャルメディア経由でファイルを共有できるようにする",
    "Allow resharing" : "再共有を許可する",
    "Allow sharing with groups" : "グループ共有を許可する",
    "Restrict users to only share with users in their groups" : "グループ内のユーザーでのみ共有するように制限する",
    "Restrict users to only share with groups they are member of" : "ユーザーの所属するグループのメンバーのみと共有可能とする",
    "Allow users to send mail notification for shared files to other users" : "他ユーザーへの共有ファイルに関するメール通知の送信をユーザーに許可する",
    "Exclude groups from sharing" : "共有可能なグループから除外する",
    "These groups will still be able to receive shares, but not to initiate them." : "このグループでは、フォルダー共有を開始することはできませんが、共有されたフォルダーを参照することはできます。",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "共有ダイアログでのユーザー名の自動補完を有効にする。このチェックを無効にした場合は、完全なユーザー名を入力する必要があります。",
    "Restrict enumeration to group members" : "グループのメンバーのみ列挙する",
    "Extra field to display in autocomplete results" : "オートコンプリートの結果に表示する追加のフィールド",
    "None" : "なし",
    "User ID" : "ユーザーID",
    "Email address" : "メールアドレス",
    "Privacy Policy URL:" : "プライバシーポリシーURL:",
    "Privacy Policy URL" : "プライバシーポリシーURL",
    "Save" : "保存",
    "Everything (fatal issues, errors, warnings, info, debug)" : "すべて (致命的な問題、エラー、警告、情報、デバッグ)",
    "Info, warnings, errors and fatal issues" : "情報、警告、エラー、致命的な問題",
    "Warnings, errors and fatal issues" : "警告、エラー、致命的な問題",
    "Errors and fatal issues" : "エラー、致命的な問題",
    "Fatal issues only" : "致命的な問題のみ",
    "Log" : "ログ",
    "What to log" : "ログ出力対象",
    "Download logfile (%s)" : "ログファイルをダウンロード (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "ログファイルが100MB以上あります。ダウンロードに時間がかかります！",
    "Login" : "ログイン",
    "Plain" : "平文",
    "NT LAN Manager" : "NT LAN マネージャー",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "メールサーバー",
    "The config file is read only. Please adjust your setup by editing the config file manually." : "設定ファイルが読取専用です。設定ファイルを手で編集してセットアップを調整してください。",
    "In a clustered setup please make sure to sync the config.php file across all nodes." : "クラスタ化されたセットアップでは全てのノードでconfig.phpを確実に同期してください。",
    "This is used for sending out notifications." : "通知を送信する際に使用します。",
    "Send mode" : "送信モード",
    "Encryption" : "暗号化",
    "From address" : "送信元アドレス",
    "mail" : "mail",
    "Authentication method" : "認証方法",
    "Authentication required" : "認証を必要とする",
    "Server address" : "サーバーアドレス",
    "Port" : "ポート",
    "Credentials" : "資格情報",
    "SMTP Username" : "SMTPユーザー名",
    "SMTP Password" : "SMTP パスワード",
    "Store credentials" : "資格情報を保存",
    "Test email settings" : "メール設定のテスト",
    "Send email" : "メールを送信",
    "Security & setup warnings" : "セキュリティ＆セットアップ警告",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHPのシステム環境変数が正しく設定されていないようです。getenv(\"PATH\") コマンドでテストして何も値を返さないことを確認してください。",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "PHP設定の注意事項と php-fpmを利用する場合のサーバー向け設定を <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\"> インストールドキュメント ↗</a> で確認してください。",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "\"config\"は読み取り専用になってます。そのためにWEBインターフェースで設定できません可能性があります。さらに、更新時に\"config\"ファイルを書き込み権限を与えることが必要",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHPでインラインドキュメントブロックを取り除く設定になっています。これによりコアアプリで利用できないものがいくつかあります。",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "これは、Zend OPcacheやeAccelerator 等のキャッシュ/アクセラレーターが原因かもしれません。",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%2$s よりも古いバージョンの %1$s がインストールされています。安定した稼働とパフォーマンスの観点から、新しいバージョンの %1$s にアップデートすることをお勧めします。",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP のモジュール 'fileinfo' が見つかりません。mimeタイプの検出を精度良く行うために、このモジュールを有効にすることを強くお勧めします。",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "ファイルの書き込み時のロックが無効になっており、競合時に問題となる可能性があります。この問題を避ける為に config.php 中の 'filelocking.enabled' を有効にしてください。詳細については、<a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">ドキュメント↗ </a>を参照してください。",
    "Transactional file locking should be configured to use memory-based locking, not the default slow database-based locking. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "トランザクションによるファイルのロックは、既定の低速データベースによるロックではなく、メモリベースによるロックを使用するように構成する必要があります。詳細については、<a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">ドキュメント↗</a> を参照してください。",
    "System locale can not be set to a one which supports UTF-8." : "システムロケールを UTF-8 をサポートするロケールに設定できません。",
    "This means that there might be problems with certain characters in file names." : "これは、ファイル名の特定の文字に問題があることを意味しています。",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "次のロケールをサポートするには、システムに必要なパッケージをインストールすることを強くおすすめします: %s。",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "URLがドメインのルート(/)で終わっていない場合で、システムのcronを利用している場合は、URLの生成に問題が発生します。その場合は、config.php ファイルの中の \"overwrite.cli.url\" オプションをインストールしたwebrootのパスに設定してください。(推奨: \"%s\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLiteがデータベースとして使用されています。大規模な運用では別のデータベースに切り替えることをお勧めします。",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "特にデスクトップクライアントをファイル同期に使用する場合，SQLiteは非推奨です．",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "他のデータベースに移行する場合はコマンドラインツール: 'occ db:convert-type' を使うか、<a target=\"_blank\" rel=\"noreferrer\" href=\"%s\"> ドキュメント ↗</a>を参照してください。",
    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "OS上のcronを利用することをお勧めします。その他のcron利用と同じようにパフォーマンスと信頼性がもたらされます。",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "CLI から cronジョブを実行することができませんでした。次の技術的なエラーが発生しています：",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "<a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">インストールガイド ↗</a>をもう一度チェックして、<a href=\"#log-section\">ログ</a> にあるエラーまたは警告について確認してください。",
    "All checks passed." : "すべてのチェックに合格しました。",
    "System Status" : "システムステータス",
    "Tips & tricks" : "ヒントとコツ",
    "How to do backups" : "バックアップ方法",
    "Performance tuning" : "パフォーマンスチューニング",
    "Improving the config.php" : "config.phpの改善",
    "Theming" : "テーマ",
    "Hardening and security guidance" : "堅牢化とセキュリティガイダンス",
    "Get the apps to sync your files" : "ファイルを同期するアプリを取得しましょう",
    "Desktop client" : "デスクトップクライアント",
    "Android app" : "Androidアプリ",
    "iOS app" : "iOSアプリ",
    "Show First Run Wizard again" : "初回ウィザードを再表示する",
    "White-listed Domains" : "ホワイトリストドメイン",
    "No Domains." : "ドメインがありません。",
    "Domain" : "ドメイン",
    "Add Domain" : "ドメインを追加する",
    "Add" : "追加",
    "Profile picture" : "プロフィール画像",
    "Upload new" : "新たにアップロード",
    "Select from Files" : "ファイルから選択",
    "Remove image" : "画像を削除",
    "png or jpg, max. 20 MB" : "pngまたはjpg形式で最大20MB",
    "Picture provided by original account" : "オリジナルのアカウントで提供されている写真",
    "Cancel" : "キャンセル",
    "Choose as profile picture" : "プロファイル画像として選択",
    "Full name" : "氏名",
    "No display name set" : "表示名が未設定",
    "Email" : "メール",
    "Your email address" : "あなたのメールアドレス",
    "Change email" : "メールアドレスを変更",
    "Set email" : "メールアドレスを設定",
    "For password recovery and notifications" : "パスワード回復と通知用です",
    "No email address set" : "メールアドレスが設定されていません",
    "You are member of the following groups:" : "以下のグループのメンバーです:",
    "You are not a member of any groups." : "あなたはどのグループのメンバーでもありません。",
    "Username" : "ユーザーID",
    "Password" : "パスワード",
    "Unable to change your password" : "パスワードを変更することができません",
    "Current password" : "現在のパスワード",
    "New password" : "新しいパスワード",
    "Change password" : "パスワードを変更",
    "Help translate" : "翻訳に協力する",
    "You are using %s" : "%s使用中",
    "You are using %s of %s (%s %%)" : "%s/%s使用中（%s%%）",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : " {communityopen}ownCloud community{linkclose} によって開発されています。{githubopen}ソースコード{linkclose} は {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose} によってライセンスされます。",
    "Sessions" : "セッション",
    "Browser" : "ブラウザー",
    "Most recent activity" : "最新のアクティビティ",
    "App passwords / tokens" : "パスワード／トークンを追加する",
    "You've linked these apps." : "あなたは、これらのアプリに紐付けられています。",
    "Name" : "名前",
    "App name" : "アプリ名",
    "Create new app passcode" : "新しいパスコードを作成する",
    "Use the credentials below to configure your app or device." : "アプリや端末を設定するのに以下の認証情報を使用する。",
    "Password / Token" : "パスワード/トークン",
    "Done" : "完了",
    "Version" : "バージョン",
    "Confirm Password" : "パスワードの確認",
    "Set password" : "パスワードを設定",
    "Personal" : "個人",
    "Admin" : "管理",
    "Settings" : "設定",
    "Show enabled/disabled option" : "有効/無効オプションを表示",
    "Show storage location" : "データの保存場所を表示",
    "Show last log in" : "最終ログインを表示",
    "Show user backend" : "ユーザーバックエンドを表示",
    "Show email address" : "メールアドレスを表示",
    "Show password field" : "パスワード欄を表示",
    "Show quota field" : "クォータ欄を表示",
    "E-Mail" : "メール",
    "Admin Recovery Password" : "管理者リカバリパスワード",
    "Enter the recovery password in order to recover the users files during password change" : "パスワード変更時のユーザーのファイルを回復するため、リカバリパスワードを入力してください",
    "Add Group" : "グループを追加",
    "Group" : "グループ",
    "Everyone" : "すべてのユーザー",
    "Admins" : "管理者",
    "Default Quota" : "デフォルトのクォータサイズ",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "ストレージのクォータを入力してください (例: \"512MB\" や \"12 GB\")",
    "Unlimited" : "無制限",
    "Other" : "その他",
    "Full Name" : "名前",
    "Group Admin for" : "グループ管理者",
    "Quota" : "クォータ",
    "Storage Location" : "データの保存場所",
    "User Backend" : "ユーザーバックエンド",
    "Last Login" : "最終ログイン",
    "change full name" : "名前を変更",
    "set new password" : "新しいパスワードを設定",
    "change email address" : "メールアドレスを変更",
    "Default" : "デフォルト"
},
"nplurals=1; plural=0;");
